@@ -14,7 +14,7 @@ structure(list(maxtemp = c(18, 18, 20, 20, 20, 20, 22, 22, 22,
     22, 24, 7, 9, 12, 14, 18, 20, 23, 26, 5, 8, 11, 13, 16, 19, 
     22, 25, 6, 9, 12, 15, 18, 21, 25, 5, 7, 10, 13, 16, 19, 22, 
     5, 7, 10, 13, 17, 20, 5, 8, 11, 14, 17)), .Names = c("maxtemp", 
-"mintemp", "dewpoint"), class = "data.frame", row.names = c("1", 
+"mintemp", "dewpt"), class = "data.frame", row.names = c("1", 
 "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
 "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", 
 "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", 
